<?php
class KT_Discount_Code_Settings {
	/**
	 * Autoload method
	 *
	 * @return void
	 */
	public function __construct() {
		add_action( 'admin_menu', array( &$this, 'register_menu' ) );
		add_action( 'admin_init', array( $this, 'initialize_options' ) );

		add_action( 'admin_enqueue_scripts', array( $this, 'admin_scripts' ) );
		add_action( 'kt-discount-code-before-form', array( $this, 'save' ) );

		add_action( 'wp_ajax_kt_discount_code_clear_field_cache',  array( $this, 'clear_cache' ) );
	}
	function admin_scripts() {
		wp_enqueue_style( 'kt-discount-code', KT_DISCOUNT_CODE_PLUGIN_URL . '/css/backend.css' );
		wp_enqueue_script( 'kt-discount-code-script', KT_DISCOUNT_CODE_PLUGIN_URL . '/js/script.js' , array( 'jquery' ) );
		wp_enqueue_script( 'clipboard', KT_DISCOUNT_CODE_PLUGIN_URL . '/js/clipboard.min.js' , array( 'jquery' ) );
	}

	/**
	 * Register submenu
	 *
	 * @return void
	 */
	public function register_menu() {
		add_menu_page( 'KT Discount Code', 'KT Discount Code', 'manage_options', 'kt-discount-code', array( $this, 'kt_discount_code' ), 'dashicons-welcome-widgets-menus', 90 );
		add_submenu_page( 'kt-discount-code', 'Einstellungen', 'Einstellungen', 'manage_options', 'kt-discount-code-settings', array( &$this, 'settings_layout' ) );
	}

	public function kt_discount_code() {

		$license_status = get_option( 'kt_discount_code_license_status' );
		if ( empty( $license_status ) || $license_status !== 'valid') {
			echo '<h2>Please enter a valid license key.</h2>'; return;
		}


		do_action( 'kt-discount-code-before-form' );

		$fields = $this->get_kt_fields();

		$kt_discount_code_field = get_option( 'kt_discount_code_field' );
		$kt_discount_code = get_option( 'kt_discount_code' );
		$outbound_link = add_query_arg(array(
			'klicktipp-outbound'=>'true',
			'discount-code' => 'true'
		), home_url());


		$html = '<div id="kt-discount-code">
		<div class="kt-discount-code-page-container">

		<form action="" method="post">
		<div class="kt-domain-dropdown-container">
		<h2>Feld auswählen</h2>
		<select name= "kt_discount_code_field">';
		foreach ( $fields as  $field_id => $kt_field_label ) {
			$html .= '<option value="' . $field_id . '" ' . selected( $field_id, $kt_discount_code_field, false ) . '>' . $kt_field_label . ' </option>';
		}
		$html .= '</select>
			<a class="button kt_discount_code_clear-field-cache-btn" href="javascript:void(0)">Klick-Tipp Felder neu laden</a>
		</div>

			<h2> Coupon hinzufügen </h2>';

		if ( empty( $kt_discount_code ) ) {
			$kt_discount_code = array(
				0=>'',
			);
		}

		foreach ( $kt_discount_code as $kt_discount_code_key => $kt_discount_code_value ) {
			$html .= '<div class="kt-discount-code-container" id= "kt-discount-code-input-container">';
			$kt_discount_code_key += 1;
			$html .= '<span class="kt-discount-code-serial-no">' . $kt_discount_code_key . ' </span>';
			$html .= '<input type=text class="kt-discount-code-box" name="kt_discount_code[]" value= "' . $kt_discount_code_value . '">';
			$html .= '<a href="#" class="kt-discount-code-add-btn kt-action-btn">
			<span class="dashicons dashicons-plus-alt"></span>
		</a><a href="#" class="kt-discount-code-delete-btn kt-action-btn">
			<span class="dashicons dashicons-minus"></span>
		</a>';
			$html .= '</div>';
		}
		$html .= '<div class="kt-domain-backlist-submit-footer">
					<input type="submit" value="Speichern" class="kt-blacklist-submit">
				</div> ' . wp_nonce_field( "kt-domain-backlist", "kt-domain-backlist" ) .
			'</form>';
			echo $html;
		?>
		<div><br/><br/>
			<h2>Klick Tipp Outbound Url</h2>
			<span class="kt-outbound-link">
				<?php echo $outbound_link; ?>
			</span>
			<span class="button" style="vertical-align: middle;"  id="copy-kt-outbound-link">In die Zwischenablage Kopieren</span>
			<script>
			(function($){
				$(function(){
					var outbound_url = "<?php  echo  $outbound_link; ?>";

					new ClipboardJS('#copy-kt-outbound-link', {
						text: function(trigger) {
							//console.log(trigger)
							return $('.kt-outbound-link').text();
						}
					});
				})
			})(jQuery)
			</script>
		</div>

		</div>
	</div>
		<?php

	}
	function save() {
		if ( ! isset( $_POST['kt-domain-backlist'] )
			|| ! wp_verify_nonce( $_POST['kt-domain-backlist'], 'kt-domain-backlist' ) ) {
			return;
		}
		if ( isset( $_POST['kt_discount_code_field'] ) ) {
			update_option( 'kt_discount_code_field', $_POST['kt_discount_code_field'] );
		}
		if ( isset( $_POST['kt_discount_code'] ) ) {
			update_option( 'kt_discount_code', $_POST['kt_discount_code'] );
		}



	}

	public function get_kt_tags() {
		$kt_tags = get_transient( 'kt_tags' );
		if ( ! empty( $kt_tags ) ) {
			return $kt_tags;
		}else {
			$connection = kt_discount_code_connect_api();
			$message = '';
			if ( ! isset( $connection['success'] ) ) {
				$tags =   array( $connection['error'] );
			} else {
				$connector = $connection['success'];
				$tags = $connector->tag_index();
				if ( ! $tags ) {
					$tags = array( $connector->get_last_error() );
				}
				set_transient( 'kt_tags', $tags, 60 * 60 * 60 );
				$connector->logout();
			}

			return $tags;
		}
	}

	public function get_kt_fields() {
		$kt_fields = get_transient( 'kt_fields' );

		if ( ! empty( $kt_fields ) ) {
			return $kt_fields;
		}else {

			$connection = kt_discount_code_connect_api();
			$message = '';
			if ( ! isset( $connection['success'] ) ) {
				$fields =   array( $connection['error'] );
			} else {
				$connector = $connection['success'];

				$fields = $connector->field_index();

				if ( ! $fields ) {
					$fields = array( $connector->get_last_error() );
				}
				set_transient( 'kt_fields', $fields, 60 * 60 * 60 );
			}

			return $fields;
		}
	}





	/**
	 * Render submenu
	 *
	 * @return void
	 */
	public function settings_layout() { ?>
		<!-- Create a header in the default WordPress 'wrap' container -->
		<div class="wrap">

			<!-- Make a call to the WordPress function for rendering errors when settings are saved. -->
			<?php settings_errors(); ?>

			<!-- Create the form that will be used to render our options -->
			<form method="post" action="options.php">
				<?php settings_fields( 'kt_discount_code_settings' ); ?>
				<?php do_settings_sections( 'kt_discount_code_settings' ); ?>
				<?php submit_button(); ?>
			</form>

		</div><!-- /.wrap -->
<?php  }

	function initialize_options() {
		// If settings don't exist, create them.
		if ( false == get_option( 'kt_discount_code_settings' ) ) {
			add_option( 'kt_discount_code_settings' );
		} // end if

		add_settings_section(
			'kt_integration_settings_section',
			'Einstellungen',
			array( $this, 'section_callback' ),
			'kt_discount_code_settings'
		);

		add_settings_field(
			'license_key',
			'Lizenzschlüssel',
			array( $this, 'settings_field' ),
			'kt_discount_code_settings',
			'kt_integration_settings_section',
			array( 'field'=>'license_key' )
		);
		add_settings_field(
			'kt_username',
			'Klick-Tipp Benutzername',
			array( $this, 'settings_field' ),
			'kt_discount_code_settings',
			'kt_integration_settings_section',
			array( 'field'=>'kt_username' )
		);

		add_settings_field(
			'kt_password',
			'Klick-Tipp Passwort',
			array( $this, 'settings_field' ),
			'kt_discount_code_settings',
			'kt_integration_settings_section',
			array( 'field'=>'kt_password', 'type'=>'password' )
		);



		// add_settings_field(
		//  'enable_log',
		//  'Enable Logging',
		//  array( $this, 'log_field' ),
		//  'kt_discount_code_settings',
		//  'kt_discount_code_settings_section'
		// );

		//register settings
		register_setting( 'kt_discount_code_settings', 'kt_discount_code_settings' );
	}

	function section_callback() {
		echo '';
	}

	function settings_field( $args ) {
		$options = get_option( 'kt_discount_code_settings' );
		$name = $args['field'];
		$type = isset( $args['type'] ) ? $args['type'] : 'text';
		$value = ! empty( $options[$name] )? $options[$name] : '';

		// Render the output
		echo '<input type="' . $type . '" class="regular-text" id="' . $name . '" name="kt_discount_code_settings[' . $name . ']" value="' . $value . '" />';
		if ( $name == 'license_key' ) {
			$status = get_option( 'kt_discount_code_license_status' );
			$license_status = ( $status == 'valid' ) ?'Aktiv':'Inaktiv';
			echo '<input type="hidden" name="kt_discount_code_license_input" value="1" >';
			echo '<span style="font-style:italic;font-size:12px">' . $license_status . '</span>';
		}
	}

	function clear_cache(){
		delete_transient( 'kt_fields' );
		wp_die();
}

}

new KT_Discount_Code_Settings();
